/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*   Description:  a library for finding the maximum clique from a graph     */
/*                                                                           */
/*   Authors: Bharath Pattabiraman and Md. Mostofa Ali Patwary               */
/*            EECS Department, Northwestern University                       */
/*            email: {bpa342,mpatwary}@eecs.northwestern.edu                 */
/*                                                                           */
/*   Copyright, 2012, Northwestern University                                */
/*   See COPYRIGHT notice in top-level directory.                            */
/*                                                                           */
/*   Please cite the following publication if you use this package           */
/*     Bharath Pattabiraman, Mostofa Patwary, Assefaw Gebremedhin, Wei-Keng  */
/*     Liao and Alok Choudhary, Fast Algorithms for the Maximum Clique       */
/*     Problem on Massive Sparse Graphs, In the 10th Workshop on Algorithms  */
/*     and Models for the Web Graph, Cambridge, MA, 2013.                    */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#ifndef FINDCLIQUE_H_INCLUDED
#define FINDCLIQUE_H_INCLUDED

#include "graphIO.h"
#include <cstddef>
#include <iostream>
#include <sys/time.h>
#include <unistd.h>
#include <stdlib.h>
using namespace std;

#ifdef _DEBUG
int DEBUG=1;
#endif

//Function Definitions
bool fexists(const char *filename);
double wtime();
void usage(char *argv0);
int getDegree(vector<int>* ptrVtx, int idx);
void print_max_clique(vector<int>& max_clique_data);

int maxClique( CGraphIO& gio, int l_bound, vector<int>& max_clique_data );
void maxCliqueHelper( CGraphIO& gio, vector<int>* U, int sizeOfClique, int& maxClq, vector<int>& max_clique_data_inter );

int maxCliqueHeu( CGraphIO& gio );
void maxCliqueHelperHeu( CGraphIO& gio, vector<int>* U, int sizeOfClique, int& maxClq, vector<int>& max_clique_data_inter ); 

#endif 
