/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*   Description:  a library for finding the maximum clique from a graph     */
/*                                                                           */
/*   Authors: Bharath Pattabiraman and Md. Mostofa Ali Patwary               */
/*            EECS Department, Northwestern University                       */
/*            email: {bpa342,mpatwary}@eecs.northwestern.edu                 */
/*                                                                           */
/*   Copyright, 2012, Northwestern University                                */
/*   See COPYRIGHT notice in top-level directory.                            */
/*                                                                           */
/*   Please cite the following publication if you use this package           */
/*     Bharath Pattabiraman, Mostofa Patwary, Assefaw Gebremedhin, Wei-Keng  */
/*     Liao and Alok Choudhary, Fast Algorithms for the Maximum Clique       */
/*     Problem on Massive Sparse Graphs, In the 10th Workshop on Algorithms  */
/*     and Models for the Web Graph, Cambridge, MA, 2013.                    */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#ifndef _graphIO_
#define _graphIO_

#include <iostream>
#include <vector>
#include <map>
#include <fstream>
#include <sstream>
#include <float.h>
#include <string.h>

#define LINE_LENGTH 256

using namespace std;

typedef std::vector<int> IntVector;

class CGraphIO
{
public:

	CGraphIO(){ }
	virtual ~CGraphIO();

	bool readGraph(string s_InputFile, float connStrength = -DBL_MAX);
	string getFileExtension(string fileName);
	bool ReadMatrixMarketAdjacencyGraph(string s_InputFile, float connStrength = -DBL_MAX);
	bool ReadMeTiSAdjacencyGraph(string s_InputFile);
	void CalculateVertexDegrees();

	int GetVertexCount(){ return m_vi_Vertices.size() - 1; }
	int GetEdgeCount(){ return m_vi_Edges.size()/2; }
	int GetMaximumVertexDegree(){ return m_i_MaximumVertexDegree; }
	int GetMinimumVertexDegree(){ return m_i_MinimumVertexDegree; }
	double GetAverageVertexDegree(){ return m_d_AverageVertexDegree; }
	string GetInputFile(){ return m_s_InputFile; }
	
	vector <int>* GetVerticesPtr(){ return &m_vi_Vertices; }
	vector <int>* GetEdgesPtr(){ return &m_vi_Edges; }

public:
	int m_i_MaximumVertexDegree;
	int m_i_MinimumVertexDegree;
	double m_d_AverageVertexDegree;

	string 	m_s_InputFile;

	vector<int> 	m_vi_Vertices;
	vector<int>   m_vi_OrderedVertices;
	vector<int> 	m_vi_Edges;
	vector<double> 	m_vd_Values;
};

#endif
